==> haskell-prettyprinter-interp-0.2.0.0-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-interp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-interp
version:              0.2.0.0
visibility:           public
id:                   prettyprinter-interp-0.2.0.0-KoAaBrVTjZAIOjOiBczTIf
key:                  prettyprinter-interp-0.2.0.0-KoAaBrVTjZAIOjOiBczTIf
license:              BSD-2-Clause
copyright:            (C) 2022-2023, Peter Lebbing
maintainer:           peter@digitalbrains.com
author:               Peter Lebbing
homepage:             https://github.com/DigitalBrains1/prettyprinter-interp
synopsis:             Efficient interpolation for Prettyprinter
description:
    This package provides efficient interpolation
    of @[string-interpolate](https://hackage.haskell.org/package/string-interpolate)@
    quasi quoters when used
    with @[prettyprinter](https://hackage.haskell.org/package/prettyprinter)@.

category:             Data, Text
abi:                  6340d1381ac59f7c8a47fcd786995486
exposed:              True
exposed-modules:      Prettyprinter.Interpolate
import-dirs:          /usr/lib/ghc-9.4.8/site-local/prettyprinter-interp-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/prettyprinter-interp-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/prettyprinter-interp-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-interp
hs-libraries:         HSprettyprinter-interp-0.2.0.0-KoAaBrVTjZAIOjOiBczTIf
depends:
    base-4.17.2.1 prettyprinter-1.7.1-4Mn04lWp3HTA5zh48zv2n2
    string-interpolate-0.3.4.0-BKXtfhsvNU1FEOrGhSRWrc
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-interp/html/prettyprinter-interp.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter-interp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-interp-0.2.0.0-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-interp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-interp
version:              0.2.0.0
visibility:           public
id:                   prettyprinter-interp-0.2.0.0-IffzJ3znwblHrBLPCaHSU2
key:                  prettyprinter-interp-0.2.0.0-IffzJ3znwblHrBLPCaHSU2
license:              BSD-2-Clause
copyright:            (C) 2022-2023, Peter Lebbing
maintainer:           peter@digitalbrains.com
author:               Peter Lebbing
homepage:             https://github.com/DigitalBrains1/prettyprinter-interp
synopsis:             Efficient interpolation for Prettyprinter
description:
    This package provides efficient interpolation
    of @[string-interpolate](https://hackage.haskell.org/package/string-interpolate)@
    quasi quoters when used
    with @[prettyprinter](https://hackage.haskell.org/package/prettyprinter)@.

category:             Data, Text
abi:                  7dcebfbf14ec56f9782186c08d556b5b
exposed:              True
exposed-modules:      Prettyprinter.Interpolate
import-dirs:          /usr/lib/ghc-9.4.8/site-local/prettyprinter-interp-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/prettyprinter-interp-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/prettyprinter-interp-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-interp
hs-libraries:         HSprettyprinter-interp-0.2.0.0-IffzJ3znwblHrBLPCaHSU2
depends:
    base-4.17.2.1 prettyprinter-1.7.1-6KCRwZiz9dxAfJnrHaz498
    string-interpolate-0.3.4.0-17ld41HnPhvDoBjrvS42RE
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-interp/html/prettyprinter-interp.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter-interp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
